export declare const isNotDefined: <T>(value: T | null | undefined) => value is null | undefined;
export declare const isDefined: <T>(value: T | null | undefined) => value is NonNullable<T>;
export declare const isEmpty: (value: string | undefined | null) => value is undefined;
export declare const isNotEmpty: (value: string | undefined | null) => value is string;
export declare const sendRequest: <ResponseData>(params: string | {
    url: string;
    method: string;
    body?: Record<string, unknown> | FormData | undefined;
    type?: string | undefined;
    headers?: Record<string, any> | undefined;
    formData?: FormData | undefined;
    onRequest?: ((request: RequestInit) => Promise<void>) | undefined;
}) => Promise<{
    data?: ResponseData | undefined;
    error?: Error | undefined;
}>;
export declare const setLocalStorageChatflow: (chatflowid: string, chatId: string, saveObj?: Record<string, any>) => void;
export declare const getLocalStorageChatflow: (chatflowid: string) => any;
export declare const removeLocalStorageChatHistory: (chatflowid: string) => void;
export declare const getBubbleButtonSize: (size: 'small' | 'medium' | 'large' | number | undefined) => number;
export declare const setCookie: (cname: string, cvalue: string, exdays: number) => void;
/**
 * Validates dataLogin from localStorage and maps user data to cmcts:userInfo
 * @returns true if successful mapping occurred, false otherwise
 */
/**
 * Type definitions for user info API response
 */
export type UserInfoApiResponse = {
    RESULT: {
        CODE: number;
        MSG: string;
    };
    OBJRETURN: {
        data: {
            id: string;
            _id: number;
            loginname: string;
            fullname: string;
            fullnameen: string;
            email: string;
            code: string;
            mobile?: string;
            imageurl?: string;
            roleName: string[];
            techGroup: Array<{
                id: number;
                name: string;
            }>;
            permissions: Record<string, string>;
            [key: string]: any;
        };
    };
};
/**
 * Fetches user info from /api/user-info endpoint with cookies
 * @param apiHost - The API host URL
 * @param onRequest - Optional request interceptor
 * @returns Promise with user info data or error
 */
export declare const fetchUserInfo: (apiHost: string, onRequest?: ((request: RequestInit) => Promise<void>) | undefined) => Promise<{
    data?: UserInfoApiResponse;
    error?: Error;
}>;
/**
 * Maps API response to dataLogin format expected by the application
 * @param apiResponse - The API response from /api/user-info
 * @returns Mapped dataLogin object
 */
export declare const mapApiResponseToDataLogin: (apiResponse: UserInfoApiResponse) => any;
/**
 * Validates dataLogin from localStorage and maps user data to cmcts:userInfo
 * @returns true if successful mapping occurred, false otherwise
 */
export declare const validateAndMapUserInfo: () => boolean;
/**
 * Checks and initializes authentication for popup embedding
 * If dataLogin doesn't exist, fetches user info from API and creates it
 * @param apiHost - The API host URL
 * @param onRequest - Optional request interceptor
 * @returns Promise<boolean> - true if authentication is successful, false otherwise
 */
export declare const checkAndInitializeAuth: (apiHost?: string, onRequest?: ((request: RequestInit) => Promise<void>) | undefined) => Promise<boolean>;
export declare const getCookie: (cname: string) => string;
//# sourceMappingURL=index.d.ts.map